@import url('https://fonts.googleapis.com/css2?family=Poppins:wght@300;400;500;600&display=swap');

*{
    margin: 0;
    padding: 0;
    box-sizing: border-box;
    font-family: 'Ubuntu';
}
body{
    min-height: 100vh;
    display: flex;
    align-items: center;
    justify-content: center;
    /* background-color: red; */
}
.slide-container{
    max-width: 704px;
    width: 100%;
    /* background-color: #efefef; */
    padding: 0 0 20px 0 ;
}
.carousel-title{
    font-size: 35px;
    /* font-weight: 500; */
    text-align: center;
    /* padding: 0; */
    /* background-color: red; */
    color: rgb(0, 0, 0);
}
.carousel-description{
    font-size: 12px;
    color: rgb(167, 167, 167);
    text-align: center;
    padding: 0 0 20px 0;
    /* background-color: red; */
}
.slide-content{
    margin: 0 40px;
    /* background-color: red; */
    overflow: hidden;
    border-radius: 15px 15px 15px 15px;

}
.card{
    width: 300px;
    height: 450px;
    border-radius: 15px 15px 15px 15px;
    /* background-color: #efefef; */
}
.image{
    position: relative;
    border-radius: 15px;
    padding: 5px;
}
.card-img{
    width: 100%;
    border-radius: 15px 15px 15px 15px;
}
.content{
    display: flex;
    flex-direction: column;
    padding: 0 7px;
}
.title{
    font-size: 14px;
    font-weight: 500;
    padding: 2px 0;
    color: rgb(0, 0, 0);
}
.keys{
    font-size: 12px;
    color: rgb(167, 167, 167);
    text-align: left;
    padding: 2px 0;
    height: 5;
    /* background-color: green; */
}
.description{
    font-size: 12px;
    color: rgb(167, 167, 167);
    text-align: justify;
    padding: 2px 2px 10px 2px;
    height: 70px;
    /* background-color: red; */
}
.button{
    border: none;
    font-size: 14px;
    color: #FFF;
    padding: 8px 0;
    background-color: #000000;
    border-radius: 15px;
    width: 120px;
    /* margin: auto 130px 10px 0; */
    cursor: pointer;
    transition: all 0.3s ease;
}











.swiper-navBtn{
    color: #454545;
    transition: color 0.3s ease;
}
.swiper-navBtn:hover{
    color: #1b1b1b;
}
.swiper-navBtn:before
.swiper-navBtn:after{
    font-size: 40px;
}
.swiper-button-next{
    right:0;
}
.swiper-button-prev{
    left:0;
}
.swiper-pagination-bullet{
    background-color: #454545;
    opacity: 1;
}
.swiper-pagination-bullet-active{
    background-color: #1b1b1b;
}

@media  and (max-width: 768px) {
    .slide-content{
        margin: 0 10px;
    }
    .swiper-navBtn{
        display: none;
    }
}
